function [distance, frequency] = analyzeDistances(PSD_polar, frequencies_polar)

% Copyright 2015 Kimmo Kartasalo
% Tampere University of Technology, Tampere, Finland
% http://www.tut.fi/cytospectre
% Email: kimmo.kartasalo@tut.fi
% 
% This file is part of CytoSpectre.
% 
% CytoSpectre is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CytoSpectre is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with CytoSpectre.  If not, see <http://www.gnu.org/licenses/>.

% Calculate the spatial frequency distribution as the marginal distribution
% of the polar spectrum and represent as a pdf.
marginal_polar = sum(PSD_polar,1);
frequency.distribution = marginal_polar/sum(marginal_polar);
frequency.polar = frequencies_polar;

% Convert the polar PSD to wavelength form.
[PSD_wl, polarwl] = frequencyToWavelength(PSD_polar, frequency.polar);
% Calculate the wavelength distribution as the marginal distribution
% of the polar wavelength spectrum.
marginal_polar_wl = sum(PSD_wl,1);

% INTERPOLOINTI
% Interpolate to obtain uniform sampling.
numberofpoints = (max(polarwl)-min(polarwl))/(polarwl(2)-polarwl(1));
distance.polar = linspace(min(polarwl),max(polarwl),numberofpoints);
distance.distribution = interp1(polarwl,marginal_polar_wl,distance.polar,'linear');
% EI INTERPOLOINTIA
% distance.polar=polarwl;
% distance.distribution = marginal_polar_wl;
% BINSIZE-KORJAUS
%binsizes = distance.polar(2:end)-distance.polar(1:end-1);
%binsizes =[binsizes(1) binsizes'];
%distance.distribution = binsizes.*distance.distribution;

% Calculate summary statistics.
distance.distribution = distance.distribution/sum(distance.distribution);
[distance.mean, distance.median, distance.max, ~, distance.std, ~, ~] = statsFromPDF(distance.distribution, distance.polar, 0);
distance = orderfields(distance,{'distribution','polar','mean','median','max','std'});
