function [orientation] = analyzeOrientations_cirstatTB(PSD_polar,varargin)

% Copyright 2015 Kimmo Kartasalo
% Tampere University of Technology, Tampere, Finland
% http://www.tut.fi/cytospectre
% Email: kimmo.kartasalo@tut.fi
% 
% This file is part of CytoSpectre.
% 
% CytoSpectre is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% CytoSpectre is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with CytoSpectre.  If not, see <http://www.gnu.org/licenses/>.

% Check if 90 degree rotation is requested or not.
rotate90 = 0;
if nargin > 1
    if strcmp('rotate90',varargin{1})
        rotate90 = 1;
    end
end

% Calculate the orientation distribution as the marginal distribution
% of the polar spectrum and represent as a pdf.
marginal_polar = sum(PSD_polar,2);
orientation.distribution = marginal_polar/sum(marginal_polar);
orientation.angles = linspace(0,pi,size(PSD_polar,1))';
% Angle doubling to get the statistics right for axial data.
orientation.angles_full = linspace(0,2*pi,size(PSD_polar,1))';
% Calculate angular bin size for bias corrections.
binspacing = orientation.angles_full(2) - orientation.angles_full(1);    

% Rotate the distribution by 90 degrees if requested.
if rotate90 == 1
    orientation.distribution = [orientation.distribution(orientation.angles > pi/2); orientation.distribution(orientation.angles <= pi/2)];
end

% Calculate circular statistics.
% Mean direction.
[orientation.mean] = circ_mean(orientation.angles_full, orientation.distribution);
orientation.mean = orientation.mean/2;
% Variance.
[orientation.cvar,~] = circ_var(orientation.angles_full, orientation.distribution, binspacing);
% Standard deviation.
[orientation.astd, ~] = circ_std(orientation.angles_full, orientation.distribution, binspacing);
% Skewness.
[orientation.cskew, ~] = circ_skewness(orientation.angles_full, orientation.distribution);
% Kurtosis.
[orientation.ckurt, ~] = circ_kurtosis(orientation.angles_full, orientation.distribution);

% Convert mean to degrees.
orientation.mean = circ_rad2ang(orientation.mean);
if orientation.mean < 0
    orientation.mean = orientation.mean + 180;
end

orientation = orderfields(orientation,{'distribution','angles','angles_full','mean','cvar','astd','cskew','ckurt'});
                
    